@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2020 Red Hat, Inc.
+ * Copyright (c) 2016-2022 Red Hat, Inc.
  *
  * All rights reserved.
  *
@@ -540,6 +540,7 @@ int totemknet_nodestatus_get (
 		return (-1);
 	}
 
+	/* node_status[] has been zeroed for us in totempg.c */
 	for (i=0; i < num_links; i++) {
 		if (!instance->totem_config->interfaces[link_list[i]].configured) {
 			continue;
@@ -550,12 +551,12 @@ int totemknet_nodestatus_get (
 					   &link_status,
 					   sizeof(link_status));
 		if (res == 0) {
-			node_status->link_status[i].enabled = link_status.enabled;
-			node_status->link_status[i].connected = link_status.connected;
-			node_status->link_status[i].dynconnected = link_status.dynconnected;
-			node_status->link_status[i].mtu = link_status.mtu;
-			memcpy(node_status->link_status[i].src_ipaddr, link_status.src_ipaddr, KNET_MAX_HOST_LEN);
-			memcpy(node_status->link_status[i].dst_ipaddr, link_status.dst_ipaddr, KNET_MAX_HOST_LEN);
+			node_status->link_status[link_list[i]].enabled = link_status.enabled;
+			node_status->link_status[link_list[i]].connected = link_status.connected;
+			node_status->link_status[link_list[i]].dynconnected = link_status.dynconnected;
+			node_status->link_status[link_list[i]].mtu = link_status.mtu;
+			memcpy(node_status->link_status[link_list[i]].src_ipaddr, link_status.src_ipaddr, KNET_MAX_HOST_LEN);
+			memcpy(node_status->link_status[link_list[i]].dst_ipaddr, link_status.dst_ipaddr, KNET_MAX_HOST_LEN);
 		} else {
 			knet_log_printf (LOGSYS_LEVEL_WARNING, "knet_link_get_link_status(%d, %d) failed: %d", nodeid, link_list[i], res);
 		}
@@ -884,6 +885,36 @@ static void knet_set_access_list_config(struct totemknet_instance *instance)
 #endif
 }
 
+void totemknet_configure_log_level()
+{
+	int logsys_log_mode;
+	int knet_log_mode = KNET_LOG_INFO;
+	uint8_t s;
+
+	if (!global_instance || !global_instance->knet_handle) {
+		return;
+	}
+
+	/* Reconfigure logging level */
+	logsys_log_mode = logsys_config_debug_get("KNET");
+
+	switch (logsys_log_mode) {
+		case LOGSYS_DEBUG_OFF:
+			knet_log_mode = KNET_LOG_INFO;
+			break;
+		case LOGSYS_DEBUG_ON:
+			knet_log_mode = KNET_LOG_DEBUG;
+			break;
+		case LOGSYS_DEBUG_TRACE:
+			knet_log_mode = KNET_LOG_DEBUG;
+			break;
+	}
+	log_printf (LOGSYS_LEVEL_DEBUG, "totemknet setting log level %s", knet_log_get_loglevel_name(knet_log_mode));
+	for (s = 0; s<KNET_MAX_SUBSYSTEMS; s++) {
+		knet_log_set_loglevel(global_instance->knet_handle, s, knet_log_mode);
+	}
+}
+
 
 /* NOTE: this relies on the fact that totem_reload_notify() is called first */
 static void totemknet_refresh_config(
@@ -894,7 +925,7 @@ static void totemknet_refresh_config(
 	void *user_data)
 {
 	uint8_t reloading;
-	uint32_t value;
+	int after_reload;
 	uint32_t link_no;
 	size_t num_nodes;
 	knet_node_id_t host_ids[KNET_MAX_HOST];
@@ -912,18 +943,27 @@ static void totemknet_refresh_config(
 		return;
 	}
 
+	after_reload = (strcmp(key_name, "config.totemconfig_reload_in_progress") == 0);
+
 	knet_set_access_list_config(instance);
 
-	if (icmap_get_uint32("totem.knet_pmtud_interval", &value) == CS_OK) {
-
-		instance->totem_config->knet_pmtud_interval = value;
-		knet_log_printf (LOGSYS_LEVEL_DEBUG, "knet_pmtud_interval now %d", value);
+	if (strcmp(key_name, "totem.knet_pmtud_interval") == 0 || after_reload) {
+		knet_log_printf (LOGSYS_LEVEL_DEBUG, "knet_pmtud_interval now %u",
+		    instance->totem_config->knet_pmtud_interval);
 		err = knet_handle_pmtud_setfreq(instance->knet_handle, instance->totem_config->knet_pmtud_interval);
 		if (err) {
 			KNET_LOGSYS_PERROR(errno, LOGSYS_LEVEL_WARNING, "knet_handle_pmtud_setfreq failed");
 		}
 	}
 
+	if (strcmp(key_name, "totem.knet_mtu") == 0 || after_reload) {
+		knet_log_printf (LOGSYS_LEVEL_DEBUG, "knet_mtu now %u", instance->totem_config->knet_mtu);
+		err = knet_handle_pmtud_set(instance->knet_handle, instance->totem_config->knet_mtu);
+		if (err) {
+			KNET_LOGSYS_PERROR(errno, LOGSYS_LEVEL_WARNING, "knet_handle_pmtud failed");
+		}
+	}
+
 	/* Configure link parameters for each node */
 	err = knet_host_get_host_list(instance->knet_handle, host_ids, &num_nodes);
 	if (err != 0) {
@@ -957,6 +997,7 @@ static void totemknet_refresh_config(
 		}
 	}
 
+	/* Log levels get reconfigured from logconfig.c as that happens last in the reload */
 	LEAVE();
 }
 
@@ -1181,6 +1222,10 @@ int totemknet_initialize (
 	if (res) {
 		KNET_LOGSYS_PERROR(errno, LOGSYS_LEVEL_WARNING, "knet_handle_pmtud_setfreq failed");
 	}
+	res = knet_handle_pmtud_set(instance->knet_handle, instance->totem_config->knet_mtu);
+	if (res) {
+		KNET_LOGSYS_PERROR(errno, LOGSYS_LEVEL_WARNING, "knet_handle_pmtud_set failed");
+	}
 	res = knet_handle_enable_filter(instance->knet_handle, instance, dst_host_filter_callback_fn);
 	if (res) {
 		KNET_LOGSYS_PERROR(errno, LOGSYS_LEVEL_WARNING, "knet_handle_enable_filter failed");
@@ -1199,6 +1244,9 @@ int totemknet_initialize (
 	}
 	global_instance = instance;
 
+	/* Setup knet logging level */
+	totemknet_configure_log_level();
+
 	/* Get an fd into knet */
 	instance->knet_fd = 0;
 	res = knet_handle_add_datafd(instance->knet_handle, &instance->knet_fd, &channel);
